pub fn lazy_callback<T>() -> (LazyCallback<T>, CallbackSetter<T>)Expand description
A LazyCallback is a Callback that will be initialized at a later date. We return the ‘LazyCallback’ which is a GenericCallback. We also return a ‘CallbackSetter’ where the callback can be set at a later date.